
==========================
Frequently Asked Questions
==========================

This section contains answers to frequently asked questions or to questions
every new user would like to ask the author of django-mysql-manager.


Donations
=========

**Is this software free?**
    django-mysql-manager is released under the terms of the *Apache License version 2*,
    therefore it is free software, which you can download, use or build upon.
    However, a significant amount of time and effort has gone into developing
    this software and writing this documentation. So, the production of this
    software has not been free from cost. It is highly recommended that, if
    you use this software *in production*, you should consider making a
    donation.

**Please define use-in-production**
    *Use-in-production* refers to using this software to power a web site
    or to develop derivative works which are used to power a web site
    on the internet or in a corporate intranet.

**How much should I donate?**
    This is totally up to you. If we all made a one dollar donation to each
    piece of free software we use in production, this world would have been
    a better place for the developers of free software.

**How do I make a donation?**
    Please visit the CodeTRAX `donations page`_ which contains a PayPal_
    *donate* button. Thank you for considering making a
    donation to django-mysql-manager.

.. _`donations page`: https://source.codetrax.org/donate.html
.. _PayPal: https://www.paypal.com

**What is CodeTRAX?**
    CodeTRAX_ is a private project hosting service. It was launched by
    *George Notaras* in the first quarter of 2007 to facilitate the
    centralized management and organization of his software and
    documentation projects.

.. _CodeTRAX: http://www.codetrax.org/


Licensing
=========

**Is django-mysql-manager free-software?**
    django-mysql-manager is released under the terms of the *Apache License version 2*,
    therefore it is free software. Please read the included ``LICENSE`` file
    carefully for the full legal text and also the ``NOTICE`` file
    which contains copyright and other important notes and statements that
    govern your use of this software, especially if you plan to release
    works that derive from this software.

**What name should I use for works that derive from your software?**
    You can use any name you like as long as it *does not contain the name
    of the original project*. This is clearly stated in the ``NOTICE`` file.
    Please note that this restriction also applies to public forks of the
    original project's source code repository. A different name must be used
    to name your fork.


Contributions
=============

**This looks like an interesting project, how can I contribute?**
    The best way to contribute to the project is to test the software for
    possible bugs and also suggest new features or provide feedback
    regarding the current feature set at the project's `issue tracker`_.
    Patches are also much appreciated.
    
**How do I submit patches?**
    Please open a ticket at the project's `issue tracker`_ and attach
    your patches there. Patches sent via personal email are not generally
    accepted. The patch must be contributed to the project using a
    public facility, either an issue tracker or a mailing list.

.. _`issue tracker`: http://www.codetrax.org/projects/django-mysql-manager/issues

**Can I license my contributed patches under a different license?**
    This is not possible. All contributions to this project are under
    the terms and conditions of the *Apache License version 2* and no
    additional terms can be set by the contributor.

**Is there a mailing list?**
    Currently there is no dedicated mailing list for this project. You
    may ask your questions in the project's `Community Support Forums`_.
    
.. _`Community Support Forums`: http://www.codetrax.org/projects/django-mysql-manager/boards

**I have a question related to the development of this software. Can I email you?**
    Certainly. But, please, note that it might take a while until I get back
    to you. Unfortunately, I am not always available via email. Thanks for
    your understanding.


Support
=======

**I have a support question. Can I email you?**
    No. It is not possible to answer questions via email about how to integrate
    this application into your Django project or into your own Django app. This
    is not because I do not want to, but because I do not have the time to do
    so. Sorry.

**I have asked a question in the public forums but noone has answered**
    Please understand that this might happen in forums that are supported
    by a community of volunteers.

**I am looking for commercial support**
    Unfortunately, commercial support is not available at this time.


Various
=======

**Which URL should I use to link to django-mysql-manager?**
    Several places on the web are used to make the django-mysql-manager
    releases, source code, documentation available to the public and also
    provide public facilities for project management, issue tracking and
    community support forums. All this information being scattered in several
    web sites can bring confusion when you want to refer to this project.
    Please, use the URL to the page of the development website::
    
        http://www.codetrax.org/projects/django-mysql-manager
    
    This page contains links to all the public facilities used by
    django-mysql-manager. Thank you and apologies for the inconvenience.

